@@ -194,6 +194,9 @@ class Browser
   var $BeginRow;
   var $CloseRow;
   var $BeginRowArgs;
+  var $BeginExtraRow;
+  var $CloseExtraRow;
+  var $BeginExtraRowArgs;
   var $Totals;
   var $TotalFuncs;
   var $ExtraRows;
@@ -604,6 +607,31 @@ class Browser
   }
 
 
+  /**
+  * Set the format for an extra output row.
+  *
+  * Like Browser::RowFormat(), but used for formatting additional / extra rows
+  * created with Browser::AddRow(). Defaults to the format set with
+  * Browser::RowFormat() if unset.
+  *
+  * @param string $beginrow The new printf format for the start of the extra row.
+  * @param string $closerow The new string for the close of the extra row.
+  * @param string $rowargs ... The row arguments which will be sprintf'd into
+  * the $beginrow format for each extra row
+  */
+  function ExtraRowFormat( $beginrow, $closerow, $rowargs )
+  {
+    $argc = func_num_args();
+    $this->BeginExtraRow = func_get_arg(0);
+    $this->CloseExtraRow = func_get_arg(1);
+
+    $this->BeginExtraRowArgs = array();
+    for( $i=2; $i < $argc; $i++ ) {
+      $this->BeginExtraRowArgs[] = func_get_arg($i);
+    }
+  }
+
+
   /**
   * This method is used to build and execute the database query.
   *
@@ -788,10 +816,17 @@ class Browser
 
 
     if ( count($this->ExtraRows) > 0 ) {
+      if ( !isset($this->BeginExtraRow) )
+        $this->BeginExtraRow = $this->BeginRow;
+      if ( !isset($this->CloseExtraRow) )
+        $this->CloseExtraRow = $this->CloseRow;
+      if ( !isset($this->BeginExtraRowArgs) )
+        $this->BeginExtraRowArgs = $this->BeginRowArgs;
+
       foreach( $this->ExtraRows AS $k => $v ) {
         $BrowserCurrentRow = (object) $v;
         // Work out the answers to any stuff that may be being substituted into the row start
-        foreach( $this->BeginRowArgs AS $k => $fld ) {
+        foreach( $this->BeginExtraRowArgs AS $k => $fld ) {
           if ( isset( $BrowserCurrentRow->{$fld} ) ) {
             $rowanswers[$k] = $BrowserCurrentRow->{$fld};
           }
@@ -807,7 +842,7 @@ class Browser
         }
 
         // Start the row
-        $row_html = vsprintf( preg_replace("/#@even@#/", ($this->Query->rownum() % 2), $this->BeginRow), $rowanswers);
+        $row_html = vsprintf( preg_replace("/#@even@#/", ($this->Query->rownum() % 2), $this->BeginExtraRow), $rowanswers);
 
         if ( isset($this->match_column) && isset($this->match_value) && $BrowserCurrentRow->{$this->match_column} == $this->match_value ) {
           $row_html .= call_user_func( $this->match_function, $BrowserCurrentRow );
@@ -820,7 +855,7 @@ class Browser
         }
 
         // Finish the row
-        $row_html .= preg_replace("/#@even@#/", ($this->Query->rownum() % 2), $this->CloseRow);
+        $row_html .= preg_replace("/#@even@#/", ($this->Query->rownum() % 2), $this->CloseExtraRow);
         $this->current_row = $BrowserCurrentRow;
         $html .= preg_replace_callback("/##([^#]+)##/", array( &$this, "ValueReplacement"), $row_html );
       }
