@@ -85,7 +85,7 @@
 
                     $posEnd = strpos(strtoupper($line), vComponent::KEYEND);
                     if($posEnd !== false && $posEnd == 0){
-                        $thisEnd = substr($line, vComponent::KEYENDLENGTH);
+                        $thisEnd = strtoupper(substr($line, vComponent::KEYENDLENGTH));
                         if($thisEnd == $this->type){
                             $this->seekEnd = $seek;
                             //$iterator->next();
@@ -653,21 +653,21 @@
             }
 
             try {
-	            if ( is_array($new_component) ) {
-	                foreach( $new_component AS $k => $v ) {
-	                    $this->components[] = $v;
-	                    if ( !method_exists($v,'setMaster') ) fatal('Component to be added must be a vComponent');
-	                    $v->setMaster($this->master);
-	                }
-	            }
-	            else {
-	                if ( !method_exists($new_component,'setMaster') ) fatal('Component to be added must be a vComponent');
-	            	$new_component->setMaster($this->master);
-	            	$this->components[] = $new_component;
-	            }
+                if ( is_array($new_component) ) {
+                    foreach( $new_component AS $k => $v ) {
+                        $this->components[] = $v;
+                        if ( !method_exists($v,'setMaster') ) fatal('Component to be added must be a vComponent');
+                        $v->setMaster($this->master);
+                    }
+                }
+                else {
+                    if ( !method_exists($new_component,'setMaster') ) fatal('Component to be added must be a vComponent');
+                    $new_component->setMaster($this->master);
+                    $this->components[] = $new_component;
+                }
             }
             catch( Exception $e ) {
-            	fatal();
+                fatal();
             }
         }
 
@@ -915,7 +915,7 @@
         case 'urn:ietf:params:xml:ns:carddav:is-defined':
           if ( count($this->properties) == 0 && count($this->components) == 0 ) return false;
           break;
-        
+
         case 'urn:ietf:params:xml:ns:caldav:is-not-defined':
         case 'urn:ietf:params:xml:ns:carddav:is-not-defined':
           if ( count($this->properties) > 0 || count($this->components) > 0 ) return false;
@@ -927,9 +927,9 @@
           $subfilter = $v->GetContent();
 //          dbg_error_log( 'vCalendar', ":TestFilter: Found '%d' (of %d) subs of type '%s'",
 //                       count($subcomponents), count($this->components), $v->GetAttribute('name') );
-          $subtag = $subfilter[0]->GetNSTag(); 
+          $subtag = $subfilter[0]->GetNSTag();
           if ( $subtag == 'urn:ietf:params:xml:ns:caldav:is-not-defined'
-          			 || $subtag == 'urn:ietf:params:xml:ns:carddav:is-not-defined' ) {
+            || $subtag == 'urn:ietf:params:xml:ns:carddav:is-not-defined' ) {
             if ( count($properties) > 0 ) {
 //              dbg_error_log( 'vComponent', ":TestFilter: Wanted none => false" );
               return false;
@@ -937,7 +937,7 @@
           }
           else if ( count($subcomponents) == 0 ) {
             if ( $subtag == 'urn:ietf:params:xml:ns:caldav:is-defined'
-          			 || $subtag == 'urn:ietf:params:xml:ns:carddav:is-defined' ) {
+              || $subtag == 'urn:ietf:params:xml:ns:carddav:is-defined' ) {
 //              dbg_error_log( 'vComponent', ":TestFilter: Wanted some => false" );
               return false;
             }
@@ -961,7 +961,7 @@
           dbg_error_log( 'vCalendar', ":TestFilter: Found '%d' props of type '%s'", count($properties), $v->GetAttribute('name') );
           $subtag = $subfilter[0]->GetNSTag();
           if ( $subtag == 'urn:ietf:params:xml:ns:caldav:is-not-defined'
-          			 || $subtag == 'urn:ietf:params:xml:ns:carddav:is-not-defined' ) {
+            || $subtag == 'urn:ietf:params:xml:ns:carddav:is-not-defined' ) {
             if ( count($properties) > 0 ) {
 //              dbg_error_log( 'vCalendar', ":TestFilter: Wanted none => false" );
               return false;
@@ -969,7 +969,7 @@
           }
           else if ( count($properties) == 0 ) {
             if ( $subtag == 'urn:ietf:params:xml:ns:caldav:is-defined'
-            			 || $subtag == 'urn:ietf:params:xml:ns:carddav:is-defined' ) {
+              || $subtag == 'urn:ietf:params:xml:ns:carddav:is-defined' ) {
 //              dbg_error_log( 'vCalendar', ":TestFilter: Wanted some => false" );
               return false;
             }
