@@ -139,7 +139,7 @@ class vProperty extends vObject {
         while( true );
         $values = substr($unescaped, $splitpos+1);
 
-        $possiblecontent = preg_replace( "/\\\\([,:\"\\\\])/", '$1', $values);
+        $possiblecontent = preg_replace( "/\\\\([,;:\"\\\\])/", '$1', $values);
         // in case if the name was set manualy content by function Valued
         // -> don't reset it by $rendered data
         if(!isset($this->content)){
@@ -307,7 +307,7 @@ class vProperty extends vObject {
 //    dbg_error_log('PUT', $this->name.$this->RenderParameters().':'.$this->content );
     }
 
-    /**                                                                
+    /**
      * Clear all parameters, or the parameters matching a particular type
      * @param string|array $type The type of parameters or an
      * array associating parameter names with true values: array( 'PARAMETER' => true, 'PARAMETER2' => true )
@@ -379,6 +379,7 @@ class vProperty extends vObject {
         if(!isset($this->name) || !isset($this->content) || !isset($this->parameters)) {
             $this->ParseFromIterator();
         }
+
         $property = preg_replace( '/[;].*$/', '', $this->name );
         $escaped = $this->content;
         $property = preg_replace( '/^.*[.]/', '', $property ); //temporarily remove grouping prefix from CARDDAV attributes ("item1.", "item2.", etc)
@@ -391,23 +392,24 @@ class vProperty extends vObject {
             case 'RRULE':                 case 'REPEAT':                    case 'TRIGGER':               case 'RDATE':
             case 'COMPLETED':             case 'DTEND':                     case 'DUE':                   case 'DTSTART':
             case 'DTSTAMP':               case 'LAST-MODIFIED':             case 'CREATED':               case 'EXDATE':
+            case 'CATEGORIES' :
             break;
 
             /** Content escaping does not apply to these properties culled from RFC6350 / RFC2426 */
             case 'ADR':                case 'N':            case 'ORG':
             // escaping for ';' for these fields also needs to happen to the components they are built from.
+            $escaped = str_replace( '\\', '\\\\', $escaped);
             $escaped = preg_replace( '/\r?\n/', '\\n', $escaped);
             $escaped = str_replace( ',', '\\,', $escaped);
             break;
-
             /** Content escaping applies by default to other properties */
             default:
+                $escaped = str_replace( '\\', '\\\\', $escaped);
                 $escaped = preg_replace( '/\r?\n/', '\\n', $escaped);
-                $escaped = preg_replace( "/([,])/", '\\\\$1', $escaped);
+                $escaped = preg_replace( "/([,;])/", '\\\\$1', $escaped);
         }
 
         $rendered = '';
-
         $property = sprintf( "%s%s:", $this->name, $this->RenderParameters() );
         if ( (strlen($property) + strlen($escaped)) <= 72 ) {
             $rendered = $property . $escaped;
